@@ -293,7 +293,9 @@ DocumentTypeType = Literal[
     "Automation",
     "Automation.ChangeTemplate",
     "ChangeCalendar",
+    "CloudFormation",
     "Command",
+    "ConformancePackTemplate",
     "DeploymentStrategy",
     "Package",
     "Policy",
